@@ -4,8 +4,6 @@
 ;;
 ;; Author: Masatake YAMATO <jet@gyve.org>
 ;; Created: Tue May 13 19:12:23 2003
-;; Version: $Id: context-skk.el,v 1.17 2013/01/13 09:45:48 skk-cvs Exp $
-;; Last Modified: $Date: 2013/01/13 09:45:48 $
 ;;
 ;; This program is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -81,9 +79,9 @@
 ;;   $B?t$,4^$^$l$F$$$^$9!#(B
 ;;
 ;; $BFH<+$KJQ?t$r@_Dj$7$?$$>l9g!"4X?t$r=q$/I,MW$,$"$j$^$9!#(B
-;; `context-skk-custumize-functions' $B$N%I%-%e%a%s%H$K=>$$!"4X?t$r=q$-!"(B
+;; `context-skk-customize-functions' $B$N%I%-%e%a%s%H$K=>$$!"4X?t$r=q$-!"(B
 ;;
-;; (add-to-list 'context-skk-custumize-functions 
+;; (add-to-list 'context-skk-customize-functions
 ;;	        'your-on-the-fly-customize-func)
 ;;
 ;; $B$H$7$FEPO?$7$^$9!#(BM-x context-skk-dump-customize $B$K$h$k8=:_$N%]%$%s%H(B
@@ -97,7 +95,7 @@
 ;; $B$N%^%$%J!<%b!<%I$,(B on $B$K$J$C$F$$$k$3$H$r0UL#$7$^$9!#(B
 ;;
 ;; - $B%$%s%9%H!<%k(B -
-;; ~/.emacs $B$K0J2<$r5-=R$7$^$9!#(B
+;; ~/.emacs.d/init.el $B$K0J2<$r5-=R$7$^$9!#(B
 ;;
 ;; (add-hook 'skk-load-hook
 ;;	  (lambda ()
@@ -127,8 +125,12 @@
   :type 'hook
   :group 'context-skk)
 
+(make-obsolete-variable 'context-skk-custumize-functions
+			'context-skk-customize-functions
+			"DDSKK 16.2")
+
 ;;;###autoload
-(defcustom context-skk-custumize-functions 
+(defcustom context-skk-customize-functions
   '(context-skk-customize-kutouten)
   "*skk $B$K$h$kF~NO3+;OD>A0$K!"F~NO$r%+%9%?%^%$%:$9$k4X?t$rEPO?$9$k!#(B
 $B4X?t$O0J2<$N7A<0$N%G!<%?$rMWAG$H$9$k%j%9%H$rJV$9$b$N$H$9$k(B: 
@@ -199,7 +201,7 @@
      (if context-skk-mode
 	 (if (context-skk-context-check)
 	     (context-skk-insert) 
-	   (eval `(let ,(context-skk-custumize)
+	   (eval `(let ,(context-skk-customize)
 		    ad-do-it)))
        ad-do-it)))
 
@@ -213,10 +215,10 @@
   "$BF|K\8lF~NO$r<+F0E*$K(B off $B$K$7$?$$!V%3%s%F%-%9%H!W$K$$$l$P(B t $B$rJV$9(B"
   (run-hook-with-args-until-success 'context-skk-context-check-hook))
 
-(defun context-skk-custumize ()
+(defun context-skk-customize ()
   "$B%+%9%?%^%$%:$7$?$$JQ?t$HCM$NAH$rF@$k!#(B"
   (let (customized-pairs)
-    (dolist (func context-skk-custumize-functions)
+    (dolist (func context-skk-customize-functions)
       (setq customized-pairs
 	    (append 
 	     (save-excursion (funcall func))
@@ -224,9 +226,9 @@
     customized-pairs))
 
 (defun context-skk-dump-customize ()
-  "$B8=:_$N%]%$%s%H$N0LCV$K$*$1$k(B (context-skk-custumize) $B$N7k2L$rI=<($9$k!#(B"
+  "$B8=:_$N%]%$%s%H$N0LCV$K$*$1$k(B (context-skk-customize) $B$N7k2L$rI=<($9$k!#(B"
   (interactive)
-  (let ((customized-pairs (context-skk-custumize)))
+  (let ((customized-pairs (context-skk-customize)))
     (with-output-to-temp-buffer "*context-skk customize result*"
       (pp customized-pairs))))
 
