@@ -24,7 +24,7 @@
 
 ;; You should have received a copy of the GNU General Public License
 ;; along with GNU Emacs; see the file COPYING.  If not, write to the
-;; Free Software Foundation, Inc., 51 Franklin Streetreet, Fifth Floor,
+;; Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 ;; Boston, MA 02110-1301, USA.
 
 ;;; Commentary:
@@ -69,50 +69,50 @@ This is last argument in `ptexinfmt-broken-facility'.")
   "Declare a symbol FACILITY is broken if ASSERTION is nil.
 DOCSTRING will be printed if ASSERTION is nil and
 `ptexinfmt-disable-broken-notice-flag' is nil."
-  (` (let ((facility '(, facility))
-	   (docstring (, docstring))
-	   (assertion (eval '(, assertion))))
-       (put facility 'broken (not assertion))
-       (if assertion
+  `(let ((facility ',facility)
+	 (docstring ,docstring)
+	 (assertion (eval ',assertion)))
+     (put facility 'broken (not assertion))
+     (if assertion
+	 nil
+       (put facility 'broken-docstring docstring)
+       (if ptexinfmt-disable-broken-notice-flag
 	   nil
-	 (put facility 'broken-docstring docstring)
-	 (if ptexinfmt-disable-broken-notice-flag
-	     nil
-	   (message "BROKEN FACILITY DETECTED: %s" docstring))))))
+	 (message "BROKEN FACILITY DETECTED: %s" docstring)))))
 
 (put 'ptexinfmt-defun-if-broken 'lisp-indent-function 'defun)
 (defmacro ptexinfmt-defun-if-broken (&rest args)
   "Redefine a function just like `defun' if it is considered broken."
   (let ((name (list 'quote (car args))))
     (setq args (cdr args))
-    (` (prog1
-	   (, name)
-	 (if (get (, name) 'broken)
-	     (defalias (, name)
-	       (function (lambda (,@ args)))))))))
+    `(prog1
+	 ,name
+       (if (get ,name 'broken)
+	   (defalias ,name
+	     (function (lambda ,@args)))))))
 
 (put 'ptexinfmt-defun-if-void 'lisp-indent-function 'defun)
 (defmacro ptexinfmt-defun-if-void (&rest args)
   "Define a function just like `defun' unless it is already defined."
   (let ((name (list 'quote (car args))))
     (setq args (cdr args))
-    (` (prog1
-	   (, name)
-	 (if (fboundp (, name))
-	     nil
-	   (defalias (, name)
-	     (function (lambda (,@ args)))))))))
+    `(prog1
+	 ,name
+       (if (fboundp ,name)
+	   nil
+	 (defalias ,name
+	   (function (lambda ,@args)))))))
 
 (put 'ptexinfmt-defvar-if-void 'lisp-indent-function 'defun)
 (defmacro ptexinfmt-defvar-if-void (&rest args)
   "Define a variable just like `defvar' unless it is already defined."
   (let ((name (car args)))
     (setq args (cdr args))
-    (` (prog1
-	   (defvar (, name))
-	 (if (boundp '(, name))
-	     nil
-	   (defvar (, name) (,@ args)))))))
+    `(prog1
+	 (defvar ,name)
+       (if (boundp ',name)
+	   nil
+	 (defvar ,name ,@args)))))
 
 ;; sort -fd
 (ptexinfmt-broken-facility texinfo-format-printindex
@@ -518,7 +518,7 @@ For example, @verb\{|@|\} results in @ and
   (goto-char texinfo-command-start))
 
 ;; @,{c}	==>	c,	cedilla accent
-(put ', 'texinfo-format 'texinfo-format-cedilla-accent)
+(put '\, 'texinfo-format 'texinfo-format-cedilla-accent)
 (ptexinfmt-defun-if-void texinfo-format-cedilla-accent ()
   (insert (texinfo-parse-arg-discard) ",")
   (goto-char texinfo-command-start))
@@ -958,67 +958,12 @@ This command is executed when texinfmt sees @item inside @multitable."
 	(texinfo-sort-region opoint (point))
       (shell-command-on-region opoint (point) "sort -fd" 1))))
 
-(ptexinfmt-broken-facility texinfo-format-separate-node ()
-  (with-temp-buffer
-    (insert (prin1-to-string (symbol-function 'texinfo-format-separate-node)))
-    (goto-char (point-min))
-    (not (search-forward "fill-paragraph" nil t nil))))
-
 (ptexinfmt-broken-facility texinfo-format-end-node ()
   (with-temp-buffer
     (insert (prin1-to-string (symbol-function 'texinfo-format-end-node)))
     (goto-char (point-min))
     (not (search-forward "fill-paragraph" nil t nil))))
 
-(ptexinfmt-defun-if-broken texinfo-format-separate-node ()
-  (let* (start
-	 (arg (texinfo-parse-line-arg))
-	 (node-name-beginning
-	  (save-excursion
-	    (re-search-backward
-	     "^File: \\w+\\(\\w\\|\\s_\\|\\.\\|,\\)*[ \t]+Node:")
-	    (match-end 0)))
-	 (node-name
-	  (save-excursion
-	    (buffer-substring-no-properties
-	     (progn (goto-char node-name-beginning) ; skip over node command
-		    (skip-chars-forward " \t")	    ; and over spaces
-		    (point))
-	     (if (search-forward
-		  ","
-		  (save-excursion (end-of-line) (point)) t) ; bound search
-		 (1- (point))
-	       (end-of-line) (point))))))
-    (texinfo-discard-command) ; remove or insert whitespace, as needed
-    (delete-region (save-excursion (skip-chars-backward " \t\n") (point))
-		   (point))
-    (insert (format " (%d) (*Note %s-Footnotes::)"
-		    texinfo-footnote-number node-name))
-    ;;(fill-paragraph nil)
-    (save-excursion
-      (if (re-search-forward "^@node" nil 'move)
-	  (forward-line -1))
-
-      ;; two cases: for the first footnote, we must insert a node header;
-      ;; for the second and subsequent footnotes, we need only insert
-      ;; the text of the  footnote.
-
-      (if (save-excursion
-	    (search-backward
-	     (concat node-name "-Footnotes, Up: ")
-	     node-name-beginning
-	     t))
-	  (progn		       ; already at least one footnote
-	    (setq start (point))
-	    (insert (format "\n(%d)  %s\n" texinfo-footnote-number arg))
-	    (fill-region start (point)))
-	;; else not yet a footnote
-	(insert "\n\^_\nFile: "  texinfo-format-filename
-		"  Node: " node-name "-Footnotes, Up: " node-name "\n")
-	(setq start (point))
-	(insert (format "\n(%d)  %s\n" texinfo-footnote-number arg))
-	(fill-region start (point))))))
-
 (ptexinfmt-defun-if-broken texinfo-format-end-node ()
   (let (start
 	(arg (texinfo-parse-line-arg)))
