@@ -5,10 +5,8 @@
 
 ;; Author: NAKAJIMA Mikio <minakaji@osaka.email.ne.jp>
 ;; Maintainer: SKK Development Team <skk@ring.gr.jp>
-;; Version: $Id: skk-annotation.el,v 1.241 2014/10/13 05:15:04 skk-cvs Exp $
 ;; Keywords: japanese, mule, input method
 ;; Created: Oct. 27, 2000.
-;; Last Modified: $Date: 2014/10/13 05:15:04 $
 
 ;; This file is part of Daredevil SKK.
 
@@ -396,14 +394,12 @@
 	(let ((minibuf-p (skk-in-minibuffer-p))
 	      event window)
 	  (skk-annotation-insert annotation)
-	  (cond (minibuf-p
-		 (if (setq window (get-buffer-window (skk-minibuffer-origin)))
-		     (select-window window)
-		   (other-window 1))
-		 (unless (eq (next-window) (selected-window))
-		   (delete-other-windows)))
-		(t
-		 (split-window-vertically)))
+	  (when minibuf-p
+	    (if (setq window (get-buffer-window (skk-minibuffer-origin)))
+		(select-window window)
+	      (other-window 1))
+	    (unless (eq (next-window) (selected-window))
+	      (delete-other-windows)))
 	  ;;
 	  (skk-fit-window (display-buffer skk-annotation-buffer))
 	  (when minibuf-p
@@ -776,7 +772,7 @@ NO-PREVIOUS-ANNOTATION $B$r;XDj(B (\\[Universal-Argument] \\[skk-annotation-ad
 			  (setq exit t)
 			  (apply (car url) (cdr url)))
 			 (t
-			  (funcall skk-annotation-browser-function url))))
+			  (browse-url url))))
 		 (skk-message "$BCm<a$N%=!<%9$r%V%i%&%:$7$F$$$^$9(B..."
 			      "Browsing originals for the current notes..."))
 		(t
@@ -1043,10 +1039,7 @@ information etc.  If PROC is non-nil, check the buffer for that process."
 	(font-lock-mode 0)
 	(set-buffer-multibyte t)
 	(skk-process-kill-without-query (get-buffer-process (current-buffer)))
-	(set-buffer-file-coding-system
-	 (if (eval-when-compile (<= emacs-major-version 22))
-	     'emacs-mule
-	   'utf-8-emacs))
+	(set-buffer-file-coding-system 'utf-8-emacs)
 	(set-buffer-process-coding-system 'utf-8-unix 'utf-8-unix)
 	;;
 	(skkannot-py-send-command "import DictionaryServices")
@@ -1832,17 +1825,21 @@ wgCategories.+\\($B[#Kf$52sHr(B\\|[Dd]isambiguation\\).+$" nil t)))
        word)))))
 
 (defun skkannot-url-installed-p ()
+  ;; skkannot-url-installed-p $B$N=i4|CM$O(B skk-vars.el $B$GDj5A(B
+  ;;  - featurep 'emacs $B$J$i(B t
+  ;;  - $B0J30$O(B 'untested
   (when (eq skkannot-url-installed-p 'untested)
-    ;; GNU Emacs 22 $B0J9_0J30$G(B URL $B%Q%C%1!<%8$r%F%9%H$9$k(B
+    ;; GNU Emacs $B0J30$G(B URL $B%Q%C%1!<%8$r%F%9%H$9$k(B
     (cond
      ((and (featurep 'xemacs)
 	   (= emacs-major-version 21)
 	   (= emacs-minor-version 4)
-	   (not (featurep 'un-define)))
-      ;; XEmacs 21.4 $B$G(B Mule-UCS $B$b$J$$>l9g(B
+	   (not (featurep 'un-define)))	; Mule-UCS
+      ;; XEmacs 21.4 $B$+$D(B Mule-UCS $BL$%$%s%9%H!<%k$N>l9g(B
       (setq skkannot-url-installed-p nil))
+
      (t
-      ;; Emacs 21 $B$H(B XEmacs
+      ;; $B>e5-0J30(B
       (defadvice url-hexify-string (around multibyte-char activate)
 	(setq ad-return-value
 	      (mapconcat (lambda (byte)
