@@ -135,7 +135,7 @@
 			 #'skk-emacs-circulate-modes)
 		       map)
 	  'help-echo
-	  "mouse-1: $B%b!<%I@ZBX(B($B=[4D(B), mouse-3: SKK $B%a%K%e!<(B"
+	  "mouse-1: $B%b!<%I@ZBX(B($B=[4D(B)\nmouse-3: SKK $B%a%K%e!<(B"
 	  'mouse-face
 	  'highlight)))
 
@@ -280,7 +280,8 @@
   (setq skk-icon
 	(let* ((dir (ignore-errors
 		     (file-name-directory
-		      (or (locate-file "skk/skk.xpm"
+		      (or (locate-file "skk.xpm" load-path)
+			  (locate-file "skk/skk.xpm"
 				       (list (expand-file-name
 					      "../../.."
 					      data-directory)))
@@ -725,11 +726,6 @@ TEXT $B$K$O(B `skk-tooltip-face' $B$,E,MQ$5$l$k!#(B"
 		      (<= ch (cdr skkdic-jisx0208-hiragana-block))
 		      (setq code (encode-char ch 'japanese-jisx0208)))
 		 (aset vec i (- (logand code #xFF) 32)))
-		((and (eval-when-compile (= emacs-major-version 22))
-		      (setq code (split-char ch))
-		      (eq (car code) 'japanese-jisx0208)
-		      (= (nth 1 code) skkdic-jisx0208-hiragana-block))
-		 (aset vec i (- (nth 2 code) 32)))
 		(t
 		 (aset vec i 128))))
 	(setq i (1+ i)))
@@ -780,7 +776,7 @@ TEXT $B$K$O(B `skk-tooltip-face' $B$,E,MQ$5$l$k!#(B"
 ;; advices.
 
 (defadvice tooltip-hide (after ccc-ad activate)
-  (update-buffer-local-frame-params))
+  (ccc-update-buffer-local-frame-params))
 
 
 (provide 'skk-emacs)
