@@ -4,9 +4,7 @@
 ;; Copyright (C) 1993-2000 Free Software Foundation, Inc.
 
 ;; Maintainer: SKK Development Team <skk@ring.gr.jp>
-;; Version: $Id: skk-macs.el,v 1.199 2013/03/28 11:55:19 skk-cvs Exp $
 ;; Keywords: japanese, mule, input method
-;; Last Modified: $Date: 2013/03/28 11:55:19 $
 
 ;; This file is part of Daredevil SKK.
 
@@ -41,16 +39,6 @@
 
 ;;;; macros
 
-(when (eval-when-compile (and (featurep 'emacs)
-			      (= emacs-major-version 22)))
-  (defmacro ignore-errors (&rest body)
-    "Execute BODY; if an error occurs, return nil.
-Otherwise, return result of last form in BODY."
-    `(condition-case nil
-	 (progn
-	   ,@body)
-       (error nil))))
-
 (defmacro skk-defadvice (function &rest everything-else)
   "Defines a piece of advice for FUNCTION (a symbol).
 This is like `defadvice', but warns if FUNCTION is a subr command and advice
@@ -199,15 +187,6 @@ MARKER $B$,(B nil $B$@$C$?$i!"?75,%^!<%+!<$r:n$C$FBeF~$9$k!#(B"
 	       )
 	 (move-overlay ,object ,start ,end))))))
 
-(defmacro skk-cannot-be-undone (&rest body)
-  `(let ((buffer-undo-list t)
-	 ;;buffer-read-only
-	 (modified (buffer-modified-p)))
-     (unwind-protect
-	 (progn
-	   ,@body)
-       (set-buffer-modified-p modified))))
-
 ;;;###autoload
 (put 'skk-loop-for-buffers 'lisp-indent-function 1)
 (defmacro skk-loop-for-buffers (buffers &rest body)
@@ -232,7 +211,7 @@ MARKER $B$,(B nil $B$@$C$?$i!"?75,%^!<%+!<$r:n$C$FBeF~$9$k!#(B"
 	 `(called-interactively-p ,kind))
 
 	(t
-	 ;; GNU Emacs 22 and 23.1
+	 ;; GNU Emacs 23.1
 	 ;; `called-interactively-p' takes no argument and is equivalent
 	 ;; to (called-interactively-p 'any) in later Emacs versions.
 	 `(if (eq ,kind 'interactive)
@@ -271,32 +250,19 @@ MARKER $B$,(B nil $B$@$C$?$i!"?75,%^!<%+!<$r:n$C$FBeF~$9$k!#(B"
 	(t
 	 `(facep ,face))))
 
+(defmacro skk-help-make-usage (symbol arglist)
+  (cond ((fboundp 'help--make-usage)
+	 ;; GNU Emacs 25.1 $B$+$i(B
+	 `(help--make-usage ,symbol ,arglist))
+
+	(t
+	 ;; GNU Emacs 24.1 $B$^$G(B
+	 `(help-make-usage ,symbol ,arglist))))
 
 ;;; functions.
 ;; version dependent
 ;; Many functions are derived from emu (APEL).
 
-(when (eval-when-compile (and (featurep 'emacs)
-			      (= emacs-major-version 22)))
-  ;; GNU Emacs 22 $B$^$G(B
-  ;; . char-valid-p is a built-in function in `C source code'.
-  ;;     (char-valid-p OBJECT &optional GENERICP)
-  ;;   Return t if OBJECT is a valid normal character.
-  ;;   If optional arg GENERICP is non-nil, also return t if OBJECT is
-  ;;   a valid generic character.
-  (defalias 'characterp 'char-valid-p)
-
-  ;; GNU Emacs 23 $B$+$i(B
-  ;; . char-valid-p is an alias for `characterp' in `mule.el'.
-  ;;     (char-valid-p OBJECT &optional IGNORE)
-  ;;   This function is obsolete since 23.1;
-  ;;   use `characterp' instead.
-
-  ;; . characterp is a built-in function in `C source code'.
-  ;;     (characterp OBJECT &optional IGNORE)
-  ;;   Return non-nil if OBJECT is a character.
-  )
-
 (when (eval-when-compile (featurep 'emacs))
   ;; int-char() $B$,=P8=$9$k$N$O(B skk-compute-henkan-lists() $B$N$_(B
   ;; XEmacs $B$G$O(B int-char() $B$OI8=`!)(B
@@ -469,38 +435,43 @@ but the contents viewed as characters do change.
 	 (x-display-color-p)))))
 
 (defun skk-char-to-unibyte-string (char)
+  ;; Warning: `string-make-unibyte' is an obsolete function (as of 26.1).
+  ;;          use `encode-coding-string'.
+
   (ignore-errors
     (cond
-     ((eval-when-compile (and (featurep 'emacs)
-			      (>= emacs-major-version 23)))
-      ;; GNU Emacs 23.1 or later
-      (string-make-unibyte (char-to-string char)))
+     ;; XEmacs
+     ((eval-when-compile (featurep 'xemacs))
+      (char-to-string char))
+     ;; GNU Emacs 26 $B$+$i(B
+     ((eval-when-compile (>= emacs-major-version 26))
+      (encode-coding-string (char-to-string char) 'us-ascii))
+     ;;  GNU Emacs 25 $B$^$G(B
      (t
-      (char-to-string char)))))
+      (string-make-unibyte (char-to-string char))))))
 
 (defun skk-ascii-char-p (char)
   (cond
-   ((eval-when-compile (and (featurep 'emacs)
-			    (>= emacs-major-version 23)))
-    ;; GNU Emacs 23.1 or later
+   ((eval-when-compile (featurep 'emacs))
+    ;; GNU Emacs
     (eq (char-charset char skk-charset-list) 'ascii))
+   ;; XEmacs
    (t
     (eq (char-charset char) 'ascii))))
 
 (defun skk-jisx0208-p (char)
   (cond
-   ((eval-when-compile (and (featurep 'emacs)
-			    (>= emacs-major-version 23)))
-    ;; GNU Emacs 23.1 or later
+   ((eval-when-compile (featurep 'emacs))
+    ;; GNU Emacs
     (eq (char-charset char skk-charset-list) 'japanese-jisx0208))
+   ;; XEmacs
    (t
     (eq (char-charset char) 'japanese-jisx0208))))
 
 (defun skk-jisx0213-p (char)
   (cond
-   ((eval-when-compile (and (featurep 'emacs)
-			    (>= emacs-major-version 23)))
-    ;; GNU Emacs 23.1 or later
+   ((eval-when-compile (featurep 'emacs))
+    ;; GNU Emacs
     (memq (char-charset char skk-charset-list)
 	  '(japanese-jisx0213-1
 	    japanese-jisx0213.2004-1
@@ -513,8 +484,7 @@ but the contents viewed as characters do change.
 (defun skk-split-char (ch)
   ;; http://mail.ring.gr.jp/skk/200908/msg00006.html
   (cond
-   ((eval-when-compile (and (featurep 'emacs)
-			    (>= emacs-major-version 23)))
+   ((eval-when-compile (featurep 'emacs))
     ;; C $B$N(B split-char() $B$HF1MM$N5!G=$@$,!"(Bchar-charset() $B$N8F=P$7$K$*$$$F(B
     ;; $BJ8;z=89g$NA*Br;h$r(B skk-charset-list $B$K4^$^$l$k$b$N$K@)8B$9$k!#(B
     ;; $B$3$l$ONc$($P!"(Bjapanese-jisx0208 $B$NJ8;z$,(B unicode-bmp $B$KB0$9$k!"(B
@@ -529,16 +499,18 @@ but the contents viewed as characters do change.
 	(setq code (lsh code -8))
 	(setq dimension (1- dimension)))
       (cons charset val)))
+
+   ;; XEmacs
    (t
-    ;; Emacs 22 $B$*$h$S(B XEmacs
     (split-char ch))))
 
 (defun skk-char-charset (ch &optional restriction)
   (cond
-   ((eval-when-compile (and (featurep 'emacs)
-			    (>= emacs-major-version 23)))
-    ;; GNU Emacs 23.1 or later
+   ((eval-when-compile (featurep 'emacs))
+    ;; GNU Emacs
     (char-charset ch restriction))
+
+   ;; XEmacs
    (t
     (char-charset ch))))
 
@@ -629,14 +601,12 @@ BUFFER defaults to the current buffer."
 
 (defun skk-region-active-p ()
   (cond
-   ((eval-when-compile (and (featurep 'emacs)
-			    (>= emacs-major-version 23)))
+   ((eval-when-compile (featurep 'emacs))
     (use-region-p))
+
+   ;; XEmacs
    ((eval-when-compile (featurep 'xemacs))
-    (region-active-p))
-   (t
-    ;; GNU Emacs 22.
-    (and transient-mark-mode mark-active))))
+    (region-active-p))))
 
 (put 'skk-bind-last-command-char 'lisp-indent-function 1)
 (defmacro skk-bind-last-command-char (char &rest body)
@@ -948,8 +918,7 @@ BUFFER defaults to the current buffer."
 $BBP$7$F(B emacs-mule $B$N(B encoded string $B$KJQ49$7$FHf3S$9$k!#(B
 $BHf3S$N7k2L(B str1 < str2 $B$J$i$P(B t $B$rJV$9!#(B"
   (cond
-   ((eval-when-compile (and (featurep 'emacs)
-			    (>= emacs-major-version 23)))
+   ((eval-when-compile (featurep 'emacs))
     ;; Emacs with coding system utf-8-emacs
     (skk-string-lessp-in-coding-system str1 str2 'emacs-mule))
    (t
@@ -1022,8 +991,8 @@ BUFFER defaults to the current buffer."
 
 (defun skk-find-coding-system (code)
   "CODE $B$,!"(BEmacs $B$,2r<a$9$k(B coding-system $B%7%s%\%kI=8=$G$"$l$P$=$N$^$^JV$7!"(B
-$BJ8;zNs$G$"$l$P(B $BO"A[%j%9%H(B `skk-coding-system-alist' $B$rMQ$$$F%7%s%\%kI=8=$XJQ49$9$k!#(B
-$B$3$l$i0J30!J(Bnil $B$r4^$`!K$G$"$l$P(B $B%7%s%\%k(B euc-jisx0213 $B$rJV$9!#(B"
+$BJ8;zNs$G$"$l$PO"A[%j%9%H(B `skk-coding-system-alist' $B$rMQ$$$F%7%s%\%kI=8=$XJQ49$9$k!#(B
+$B$3$l$i0J30!J(Bnil $B$r4^$`!K$G$"$l$P%7%s%\%k(B euc-jis-2004 $B$rJV$9!#(B"
   (cond ((and code
 	      (or (and (fboundp 'coding-system-p) ; GNU Emacs
 		       (coding-system-p code))
