@@ -1,3 +1,7 @@
+.git
+.gitattributes
+.gitignore
+.travis.yml
 RCS
 CVS
 not_used
@@ -13,6 +17,7 @@ dic/SKK-JISYO.L
 dic/SKK-JISYO.M
 dic/SKK-JISYO.ML
 dic/SKK-JISYO.S
+dic/SKK-JISYO.lisp
 dic/edict.doc
 jisyo-tools
 experimental/rdbms/kanjidic/kanjidic
