@@ -4,9 +4,7 @@
 
 ;; Author: GUNJI Takao <gunji@sils.shoin.ac.jp>
 ;; Maintainer: SKK Development Team <skk@ring.gr.jp>
-;; Version: $Id: skk-tutcdef.el,v 1.11 2007/04/22 02:38:28 skk-cvs Exp $
 ;; Keywords: japanese, mule, input method
-;; Last Modified: $Date: 2007/04/22 02:38:28 $
 
 ;; This file is part of Daredevil SKK.
 
@@ -54,7 +52,7 @@
    ("^" nil skk-input-by-code-or-menu)
    ("\C-@" nil skk-start-henkan)))
 
-;; (if (and (eq skk-emacs-type 'xemacs) (= emacs-major-version 20))
+;; (if (and (featurep 'xemacs) (= emacs-major-version 20))
 ;;     (progn
 ;;       (setq skk-rom-kana-base-rule-list
 ;;	    (delete '("\t" nil skk-toggle-kana) skk-rom-kana-base-rule-list))
@@ -955,9 +953,6 @@
 		   ("alu" nil "$B%t(B") ("eld" nil "$B%u(B") ("elg" nil "$B%v(B"))
 		 skk-rom-kana-rule-list)))
 
-(require 'product)
-(product-provide
-    (provide 'skk-tutcdef)
-  (require 'skk-version))
+(provide 'skk-tutcdef)
 
 ;;; skk-tutcdef.el ends here
